# Sage version information for Python scripts
# This file is auto-generated by the sage-update-version script, do not edit!
version = '9.7.rc1'
date = '2022-09-07'
banner = 'SageMath version 9.7.rc1, Release Date: 2022-09-07'
